@@ -163,6 +163,23 @@ class RosUserVpcAuthorization(
     ) -> None:
         jsii.set(self, "authType", value)
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="ignoreDeletionForbidden")
+    def ignore_deletion_forbidden(
+        self,
+    ) -> typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]]:
+        '''
+        :Property: ignoreDeletionForbidden: Whether to ignore following deletion forbidden errors when deleting:- UserAuth.DeleteForbidden.ZoneVpcExists
+        '''
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]], jsii.get(self, "ignoreDeletionForbidden"))
+
+    @ignore_deletion_forbidden.setter
+    def ignore_deletion_forbidden(
+        self,
+        value: typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]],
+    ) -> None:
+        jsii.set(self, "ignoreDeletionForbidden", value)
+
 
 @jsii.data_type(
     jsii_type="@alicloud/ros-cdk-pvtz.RosUserVpcAuthorizationProps",
@@ -172,6 +189,7 @@ class RosUserVpcAuthorization(
         "auth_channel": "authChannel",
         "auth_code": "authCode",
         "auth_type": "authType",
+        "ignore_deletion_forbidden": "ignoreDeletionForbidden",
     },
 )
 class RosUserVpcAuthorizationProps:
@@ -182,6 +200,7 @@ class RosUserVpcAuthorizationProps:
         auth_channel: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
         auth_code: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
         auth_type: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+        ignore_deletion_forbidden: typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]] = None,
     ) -> None:
         '''Properties for defining a ``ALIYUN::PVTZ::UserVpcAuthorization``.
 
@@ -189,6 +208,7 @@ class RosUserVpcAuthorizationProps:
         :param auth_channel: 
         :param auth_code: 
         :param auth_type: 
+        :param ignore_deletion_forbidden: 
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "authorized_user_id": authorized_user_id,
@@ -199,6 +219,8 @@ class RosUserVpcAuthorizationProps:
             self._values["auth_code"] = auth_code
         if auth_type is not None:
             self._values["auth_type"] = auth_type
+        if ignore_deletion_forbidden is not None:
+            self._values["ignore_deletion_forbidden"] = ignore_deletion_forbidden
 
     @builtins.property
     def authorized_user_id(
@@ -245,6 +267,16 @@ class RosUserVpcAuthorizationProps:
         result = self._values.get("auth_type")
         return typing.cast(typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]], result)
 
+    @builtins.property
+    def ignore_deletion_forbidden(
+        self,
+    ) -> typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]]:
+        '''
+        :Property: ignoreDeletionForbidden: Whether to ignore following deletion forbidden errors when deleting:- UserAuth.DeleteForbidden.ZoneVpcExists
+        '''
+        result = self._values.get("ignore_deletion_forbidden")
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]], result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
@@ -357,6 +389,23 @@ class RosZone(
     ) -> None:
         jsii.set(self, "zoneName", value)
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="ignoredStackTagKeys")
+    def ignored_stack_tag_keys(
+        self,
+    ) -> typing.Optional[typing.Union[ros_cdk_core.IResolvable, typing.List[typing.Union[builtins.str, ros_cdk_core.IResolvable]]]]:
+        '''
+        :Property: ignoredStackTagKeys: Stack tag keys to ignore
+        '''
+        return typing.cast(typing.Optional[typing.Union[ros_cdk_core.IResolvable, typing.List[typing.Union[builtins.str, ros_cdk_core.IResolvable]]]], jsii.get(self, "ignoredStackTagKeys"))
+
+    @ignored_stack_tag_keys.setter
+    def ignored_stack_tag_keys(
+        self,
+        value: typing.Optional[typing.Union[ros_cdk_core.IResolvable, typing.List[typing.Union[builtins.str, ros_cdk_core.IResolvable]]]],
+    ) -> None:
+        jsii.set(self, "ignoredStackTagKeys", value)
+
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="proxyPattern")
     def proxy_pattern(
@@ -516,6 +565,7 @@ class RosZone(
     jsii_struct_bases=[],
     name_mapping={
         "zone_name": "zoneName",
+        "ignored_stack_tag_keys": "ignoredStackTagKeys",
         "proxy_pattern": "proxyPattern",
         "remark": "remark",
         "resource_group_id": "resourceGroupId",
@@ -529,6 +579,7 @@ class RosZoneProps:
         self,
         *,
         zone_name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+        ignored_stack_tag_keys: typing.Optional[typing.Union[ros_cdk_core.IResolvable, typing.Sequence[typing.Union[builtins.str, ros_cdk_core.IResolvable]]]] = None,
         proxy_pattern: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
         remark: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
         resource_group_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
@@ -539,6 +590,7 @@ class RosZoneProps:
         '''Properties for defining a ``ALIYUN::PVTZ::Zone``.
 
         :param zone_name: 
+        :param ignored_stack_tag_keys: 
         :param proxy_pattern: 
         :param remark: 
         :param resource_group_id: 
@@ -549,6 +601,8 @@ class RosZoneProps:
         self._values: typing.Dict[str, typing.Any] = {
             "zone_name": zone_name,
         }
+        if ignored_stack_tag_keys is not None:
+            self._values["ignored_stack_tag_keys"] = ignored_stack_tag_keys
         if proxy_pattern is not None:
             self._values["proxy_pattern"] = proxy_pattern
         if remark is not None:
@@ -571,6 +625,16 @@ class RosZoneProps:
         assert result is not None, "Required property 'zone_name' is missing"
         return typing.cast(typing.Union[builtins.str, ros_cdk_core.IResolvable], result)
 
+    @builtins.property
+    def ignored_stack_tag_keys(
+        self,
+    ) -> typing.Optional[typing.Union[ros_cdk_core.IResolvable, typing.List[typing.Union[builtins.str, ros_cdk_core.IResolvable]]]]:
+        '''
+        :Property: ignoredStackTagKeys: Stack tag keys to ignore
+        '''
+        result = self._values.get("ignored_stack_tag_keys")
+        return typing.cast(typing.Optional[typing.Union[ros_cdk_core.IResolvable, typing.List[typing.Union[builtins.str, ros_cdk_core.IResolvable]]]], result)
+
     @builtins.property
     def proxy_pattern(
         self,
@@ -1206,6 +1270,7 @@ class UserVpcAuthorization(
         "auth_channel": "authChannel",
         "auth_code": "authCode",
         "auth_type": "authType",
+        "ignore_deletion_forbidden": "ignoreDeletionForbidden",
     },
 )
 class UserVpcAuthorizationProps:
@@ -1216,6 +1281,7 @@ class UserVpcAuthorizationProps:
         auth_channel: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
         auth_code: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
         auth_type: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+        ignore_deletion_forbidden: typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]] = None,
     ) -> None:
         '''Properties for defining a ``ALIYUN::PVTZ::UserVpcAuthorization``.
 
@@ -1223,6 +1289,7 @@ class UserVpcAuthorizationProps:
         :param auth_channel: Property authChannel: Authorization channel. Valid values: AUTH_CODE: Verification code authorization, to verify whether the verification code passed in by AuthCode is correct. RESOURCE_DIRECTORY: Resource directory authorization, verify whether the AuthorizedUserId and the current account have resource directory credit.When it is empty, it is the same as AUTH_CODE, that is, verification code authorization.
         :param auth_code: Property authCode: Verification code, if AuthChannel takes "AUTH_CODE" or is empty, it is mandatory.
         :param auth_type: Property authType: Authorization type.
+        :param ignore_deletion_forbidden: Property ignoreDeletionForbidden: Whether to ignore following deletion forbidden errors when deleting:- UserAuth.DeleteForbidden.ZoneVpcExists.
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "authorized_user_id": authorized_user_id,
@@ -1233,6 +1300,8 @@ class UserVpcAuthorizationProps:
             self._values["auth_code"] = auth_code
         if auth_type is not None:
             self._values["auth_type"] = auth_type
+        if ignore_deletion_forbidden is not None:
+            self._values["ignore_deletion_forbidden"] = ignore_deletion_forbidden
 
     @builtins.property
     def authorized_user_id(
@@ -1272,6 +1341,14 @@ class UserVpcAuthorizationProps:
         result = self._values.get("auth_type")
         return typing.cast(typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]], result)
 
+    @builtins.property
+    def ignore_deletion_forbidden(
+        self,
+    ) -> typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]]:
+        '''Property ignoreDeletionForbidden: Whether to ignore following deletion forbidden errors when deleting:- UserAuth.DeleteForbidden.ZoneVpcExists.'''
+        result = self._values.get("ignore_deletion_forbidden")
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]], result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
@@ -1341,6 +1418,7 @@ class Zone(
     jsii_struct_bases=[],
     name_mapping={
         "zone_name": "zoneName",
+        "ignored_stack_tag_keys": "ignoredStackTagKeys",
         "proxy_pattern": "proxyPattern",
         "remark": "remark",
         "resource_group_id": "resourceGroupId",
@@ -1354,6 +1432,7 @@ class ZoneProps:
         self,
         *,
         zone_name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+        ignored_stack_tag_keys: typing.Optional[typing.Union[ros_cdk_core.IResolvable, typing.Sequence[typing.Union[builtins.str, ros_cdk_core.IResolvable]]]] = None,
         proxy_pattern: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
         remark: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
         resource_group_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
@@ -1364,6 +1443,7 @@ class ZoneProps:
         '''Properties for defining a ``ALIYUN::PVTZ::Zone``.
 
         :param zone_name: Property zoneName: Zone name.
+        :param ignored_stack_tag_keys: Property ignoredStackTagKeys: Stack tag keys to ignore.
         :param proxy_pattern: Property proxyPattern: ZONE: completely hijack the entire zone. RECORD: Incomplete hijacking, recursive resolution agent. Default to ZONE.
         :param remark: Property remark: 50 characters at most. It can only contain numbers, Chinese, English and special characters: "_-,.，。".
         :param resource_group_id: Property resourceGroupId: Resource group id.
@@ -1374,6 +1454,8 @@ class ZoneProps:
         self._values: typing.Dict[str, typing.Any] = {
             "zone_name": zone_name,
         }
+        if ignored_stack_tag_keys is not None:
+            self._values["ignored_stack_tag_keys"] = ignored_stack_tag_keys
         if proxy_pattern is not None:
             self._values["proxy_pattern"] = proxy_pattern
         if remark is not None:
@@ -1394,6 +1476,14 @@ class ZoneProps:
         assert result is not None, "Required property 'zone_name' is missing"
         return typing.cast(typing.Union[builtins.str, ros_cdk_core.IResolvable], result)
 
+    @builtins.property
+    def ignored_stack_tag_keys(
+        self,
+    ) -> typing.Optional[typing.Union[ros_cdk_core.IResolvable, typing.List[typing.Union[builtins.str, ros_cdk_core.IResolvable]]]]:
+        '''Property ignoredStackTagKeys: Stack tag keys to ignore.'''
+        result = self._values.get("ignored_stack_tag_keys")
+        return typing.cast(typing.Optional[typing.Union[ros_cdk_core.IResolvable, typing.List[typing.Union[builtins.str, ros_cdk_core.IResolvable]]]], result)
+
     @builtins.property
     def proxy_pattern(
         self,
